// Product Search and Filter Functions
document.addEventListener('DOMContentLoaded', function() {
    // Product search functionality
    const searchInput = document.getElementById('product-search');
    const searchButton = document.getElementById('search-button');
    const productCards = document.querySelectorAll('.product_tab');
    
    if (searchInput && searchButton) {
        // Search button click
        searchButton.addEventListener('click', function() {
            performSearch();
        });
        
        // Enter key in search field
        searchInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                e.preventDefault();
                performSearch();
            }
        });
        
        function performSearch() {
            const searchTerm = searchInput.value.toLowerCase().trim();
            
            // If search is empty, show all products
            if (!searchTerm) {
                productCards.forEach(card => {
                    card.style.display = 'block';
                });
                return;
            }
            
            // Filter products based on search term
            productCards.forEach(card => {
                const productName = card.querySelector('.product_content h5 a').textContent.toLowerCase();
                const productContent = card.textContent.toLowerCase();
                
                if (productName.includes(searchTerm) || productContent.includes(searchTerm)) {
                    card.style.display = 'block';
                } else {
                    card.style.display = 'none';
                }
            });
        }
    }
    
    // Quantity increment/decrement on product detail page
    const decreaseBtn = document.getElementById('decrease-quantity');
    const increaseBtn = document.getElementById('increase-quantity');
    const quantityInput = document.getElementById('quantity');
    
    if (decreaseBtn && increaseBtn && quantityInput) {
        decreaseBtn.addEventListener('click', function() {
            let value = parseInt(quantityInput.value);
            if (value > 1) {
                quantityInput.value = value - 1;
            }
        });
        
        increaseBtn.addEventListener('click', function() {
            let value = parseInt(quantityInput.value);
            let max = parseInt(quantityInput.getAttribute('max'));
            if (value < max) {
                quantityInput.value = value + 1;
            }
        });
    }
    
    // Filter button toggle functionality
    const filterToggleBtn = document.getElementById('filter-toggle');
    const filterSidebar = document.getElementById('filter-sidebar');
    const productGrid = document.getElementById('product-grid');
    
    if (filterToggleBtn && filterSidebar && productGrid) {
        filterToggleBtn.addEventListener('click', function() {
            if (filterSidebar.style.display === 'none' || filterSidebar.style.display === '') {
                filterSidebar.style.display = 'block';
                productGrid.className = 'col-md-9'; // Adjust product grid when sidebar is shown
            } else {
                filterSidebar.style.display = 'none';
                productGrid.className = 'col-md-12'; // Restore product grid when sidebar is hidden
            }
        });
    }
    
    // Auto-apply filters when checkboxes are clicked
    const filterCheckboxes = document.querySelectorAll('.filter-checkbox');
    if (filterCheckboxes) {
        filterCheckboxes.forEach(checkbox => {
            checkbox.addEventListener('change', function() {
                applyFilters();
            });
        });
    }
    
    // Auto-apply filters when select is changed
    const filterSelect = document.querySelector('.filter-select');
    if (filterSelect) {
        filterSelect.addEventListener('change', function() {
            applyFilters();
        });
    }
    
    // Function to apply filters
    function applyFilters() {
        const categoryInputs = document.querySelectorAll('.filter-checkbox:checked');
        const sizeSelect = document.getElementById('size');
        
        // Build query string with selected filters
        let queryParams = new URLSearchParams();
        
        categoryInputs.forEach(input => {
            queryParams.append('categories[]', input.value);
        });
        
        if (sizeSelect && sizeSelect.value) {
            queryParams.append('size', sizeSelect.value);
        }
        
        // Redirect to filtered results
        window.location.href = `${window.location.pathname}?${queryParams.toString()}`;
    }
});
