@extends('layouts.main')

@section('side_bar')
    @include('layouts.side_bar')
@endsection

@section('profile')
    @include('layouts.profile')
@endsection

@section('page_title')
    <div class="mb-4">
        <h1 class="mb-2">Change Password</h1>
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb mb-0">
                <li class="breadcrumb-item"><a href="{{ route('home') }}">Dashboard</a></li>
                <li class="breadcrumb-item active" aria-current="page">Change Password</li>
            </ol>
        </nav>
    </div>
@endsection

@section('main_div')
    <div class="container-fluid px-0">
        <div class="row">
            <div class="col-lg-8 col-md-10 col-sm-12">
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-header bg-white border-0 py-3">
                        <h5 class="mb-0">Set New Password</h5>
                        @if(session('message'))
                            <div class="alert alert-info mt-3">
                                {{ session('message') }}
                            </div>
                        @endif
                    </div>
                    <div class="card-body">
                        <form action="{{ route('password.update') }}" method="POST">
                            @csrf

                            <div class="mb-4">
                                <label for="current_password" class="form-label">Current Password</label>
                                <div class="input-group">
                                    <span class="input-group-text bg-light"><i class="fas fa-lock text-muted"></i></span>
                                    <input type="password" name="current_password" id="current_password" class="form-control @error('current_password') is-invalid @enderror">
                                    <span class="input-group-text password-toggle" onclick="togglePassword('current_password', 'toggleIcon1')">
                                        <i class="fas fa-eye-slash text-muted" id="toggleIcon1"></i>
                                    </span>
                                </div>
                                @error('current_password')
                                    <div class="invalid-feedback d-block">{{ $message }}</div>
                                @enderror
                            </div>

                            <div class="mb-4">
                                <label for="new_password" class="form-label">New Password</label>
                                <div class="input-group">
                                    <span class="input-group-text bg-light"><i class="fas fa-key text-muted"></i></span>
                                    <input type="password" name="new_password" id="new_password" class="form-control @error('new_password') is-invalid @enderror">
                                    <span class="input-group-text password-toggle" onclick="togglePassword('new_password', 'toggleIcon2')">
                                        <i class="fas fa-eye-slash text-muted" id="toggleIcon2"></i>
                                    </span>
                                </div>
                                @error('new_password')
                                    <div class="invalid-feedback d-block">{{ $message }}</div>
                                @enderror
                                <small class="form-text text-muted">Password must be at least 8 characters long.</small>
                            </div>

                            <div class="mb-4">
                                <label for="new_password_confirmation" class="form-label">Confirm New Password</label>
                                <div class="input-group">
                                    <span class="input-group-text bg-light"><i class="fas fa-key text-muted"></i></span>
                                    <input type="password" name="new_password_confirmation" id="new_password_confirmation" class="form-control">
                                    <span class="input-group-text password-toggle" onclick="togglePassword('new_password_confirmation', 'toggleIcon3')">
                                        <i class="fas fa-eye-slash text-muted" id="toggleIcon3"></i>
                                    </span>
                                </div>
                            </div>

                            <div class="d-grid mt-4">
                                <button type="submit" class="btn btn-primary">Update Password</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('scripts')
<script>
    function togglePassword(inputId, iconId) {
        const passwordInput = document.getElementById(inputId);
        const toggleIcon = document.getElementById(iconId);
        
        if (passwordInput.type === 'password') {
            passwordInput.type = 'text';
            toggleIcon.classList.remove('fa-eye-slash');
            toggleIcon.classList.add('fa-eye');
        } else {
            passwordInput.type = 'password';
            toggleIcon.classList.remove('fa-eye');
            toggleIcon.classList.add('fa-eye-slash');
        }
    }
</script>
@endsection
