<?php
use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Session;

use App\Http\Controllers\login_controller;
use App\Http\Controllers\order_product_controller;
use App\Http\Controllers\user_controller;
use App\Http\Controllers\home_controller;
use App\Http\Controllers\card_detail_controller;
use App\Http\Controllers\order_detail_controller;
use App\Http\Controllers\orders_controller;
use App\Http\Controllers\cart_controller;


Route::get('/',[login_controller::class,'index'])->name('login');
Route::post('/login_form',[login_controller::class,'login'])->name('submit_login_form');
Route::get('/logout',[login_controller::class,'logout'])->name('logout');

// Password change routes
Route::get('/password/change', [App\Http\Controllers\PasswordController::class, 'showChangePasswordForm'])->name('password.change');
Route::post('/password/update', [App\Http\Controllers\PasswordController::class, 'changePassword'])->name('password.update');

Route::get('/color-settings.css', function () {
    $color = \App\Models\product_color_setting_model::first();

    $primaryColor = $color->primary_color ?? '#f06f0b';
    $secondaryColor = $color->secondary_color ?? '#000000';

    return response("
        :root {
            --primary-color: $primaryColor;
            --secondary-color: $secondaryColor;
        }
    ")->header('Content-Type', 'text/css');
});

Route::middleware(['checklogin'])->group(function () {

    // Admin routes for bulk user upload
    Route::prefix('admin')->name('admin.')->middleware(['checkAdmin'])->group(function () {
        Route::get('/users/bulk-upload', [App\Http\Controllers\Admin\UserBulkUploadController::class, 'showUploadForm'])->name('users.bulk-upload');
        Route::post('/users/bulk-upload/process', [App\Http\Controllers\Admin\UserBulkUploadController::class, 'processUpload'])->name('users.bulk-upload.process');
        Route::get('/users/bulk-upload/template', [App\Http\Controllers\Admin\UserBulkUploadController::class, 'downloadTemplate'])->name('users.bulk-upload.template');
    });

    Route::get('/card_detail/{id}',[card_detail_controller::class,'index'])->name('card_detail');
    Route::get('/card_detail/increase_quantity/{id}',[card_detail_controller::class,'increase_quantity'])->name('increase_quantity');
    Route::get('/card_detail/decrease_quantity/{id}',[card_detail_controller::class,'decrease_quantity'])->name('decrease_quantity');

    Route::get('/cart/partial', function () {
        $carts = Session::get('cart', []);
        $cart_unique_items = count($carts);

        return view('layouts.cart', compact('carts', 'cart_unique_items'));
    })->name('cart.partial');


    //---------------------------------
    Route::get('/home',[home_controller::class,'index'])->name('home');

    //--------------------------------
    Route::get('/products',[order_product_controller::class,'product_list'])->name('product_list');

    Route::get('/products/add-to-cart/{id}', [order_product_controller::class, 'add_to_cart'])->name('add_to_cart');
//    Route::post('/products/add-to-cart', [order_product_controller::class, 'add_to_cart'])->name('add_to_cart');
    Route::get('/cart/delete/{id}', [order_product_controller::class, 'delete'])->name('delete_unique_item');

    Route::get('/products/checkout', [order_product_controller::class, 'checkout'])->name('checkout');
//    Route::post('/products/checkout', [order_product_controller::class, 'checkout'])->name('checkout');


    Route::get('/products/filter_category/{id?}',[order_product_controller::class,'product_list'])->name('filter_product_list');

    //--------------------------------
    Route::get('/account/edit/{id}',[user_controller::class,'edit'])->name('edit_account');
    Route::post('/account/update/{id}',[user_controller::class,'update'])->name('update_account');

    //--------------------------------
    Route::get('/orders',[orders_controller::class,'order_list_side_cart'])->name('orders');
    Route::get('/order_detail/{id}',[order_detail_controller::class,'index'])->name('order_detail');

    //-------------------------------------
    Route::get('/cart',[cart_controller::class,'index'])->name('cart_page');


});
